#ifndef eeprom_h
#define eeprom_h

#include <Arduino.h>
#include <EEPROM.h>

struct globalData { // test flown version used 15 bytes - allowing 25
  uint8_t modelNum;
  int16_t joyMin[2]; // minimum joystick value x, y
  int16_t joyMax[2];
  int16_t joyCentre[2];
  uint8_t batteryScale; // theoretical value is 160 for a 16V input range (10K 22K divider into 5V input)
  uint8_t lowBatteryAlarm; // in tenths of volts
  uint8_t fiveButton; // non-zero value indicates a digital top/bottom/left/right joystick instead of an analogue one
};

struct modelData {  // test flown version used 37 bytes so there's room for 27 model memories
  char modelName[14]; // 13 chars but pad in case of \0 terminator
  int16_t rudderCentre; // in microSeconds (nominal 1500 centre)
  int16_t rudderRight;
  int16_t rudderLeft;
  int16_t elevatorCentre;
  int16_t elevatorUp;
  int16_t elevatorDown;  // not used for push button mode, but travel limit in joystick mode
  int16_t motorOff; // nominally 800 - 1000 uS
  int16_t motorOn;
  int16_t motorSoftStart; // time to reach set speed in milliseconds
  int16_t buttonSpeed; // nominal time for a quarter-turn of virtual escapement in milliseconds
  int16_t motorRunTime; // in seconds
  uint8_t quickBlipEnabled; // non-zero value means enabled
};

class eeprom {
  private:
    static void limitModelNumber(uint8_t *modelNumber);
    
  public:
    static char modelName[]; // temporary copy for getModelName
    static globalData gd;
    static modelData md;
    
    static void getGD(void);
    static void putGD(void);
    static void getMD(uint8_t modelNumber);
    static void putMD(uint8_t modelNumber);
    static char *getModelName(uint8_t modelNumber);
};
#endif

