#ifndef encoder_h
#define encoder_h

// 4 seems to be right usually, but change the 4 to 2 if you have to turn your encoder two clicks to alter a displayed value by one increment
#define ENCODER_COUNTS_PER_CLICK 4

#include <Arduino.h>
// rotary encoder.  Three pins one end connected to A0,GND,A2.  swap outer two to reverse direction of counting  
// Two pins other end connected to D10,GND - this is the momentary 'push' switch built into the encoder
// ceptimus 2015-08-13
class encoder {
  private:
    static uint8_t startupSynch;
    static int16_t debounce;
    static boolean clockwise; // used to detect change in turning direction which switches off any multipier
    static boolean oldClockwise;
  public:
    static uint8_t state; // used to decode gray scale - combination of previous and current readings
    static int16_t count; // internal value - two counts per 'indent' - use getCount to read in interrupt safe way
    static boolean pressed; // true for just one scan of checkEncoder() for each debounced encoder button press
    static int16_t timeout; // resets to 30,000 when encoder moved - counts down elapsed mS when idle - reaches zero after 30 seconds inactivity
    static boolean multiplying; // true when speed-up is occurring (see setMultiplier);
    static int16_t multiplier; // see setMultiplier
    static int16_t turningTime; // switches multiplier on after two seconds of turning in one direction without a one second pause

    static void start(void); // set-up the input pins and enable interrupts
    static void setMultiplier(int16_t ratio); // for speed-up when turning all one way for a while without much break.  10 normally, 6 for time.
    static void checkEncoder(uint16_t mS); // mS is milliseconds since previous check
    static int16_t change(int16_t value); 
};

#endif
